<?php

/**
 * @file
 * Admin callbacks for the Bulk SMS module.
 */

/**
 * Admin form callback.
 *
 * @param array $form
 *   A semi-populated array on which to build the form.
 * @param array $form_state
 *   The state information of the form.
 *
 * @return array
 *   The populated form array.
 */
function bulksms_admin_settings_form(array $form, array &$form_state) {
  // General settings.
  $form['general'] = [
    '#type' => 'fieldset',
    '#title' => t('General settings'),
  ];
  $form['general']['bulksms_n_accounts'] = [
    '#type' => 'numberfield',
    '#title' => t('Number of SMS gateways'),
    '#description' => t('Configure these gateways at <a href="@url">@url</a>.', [
      '@url' => url('admin/smsframework/gateways')
    ]),
    '#step' => 1,
    '#min' => 1,
    '#default_value' => variable_get('bulksms_n_accounts', 1),
  ];

  // Debug settings.
  $form['debug'] = [
    '#type' => 'fieldset',
    '#title' => t('Debug settings'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  ];
  $form['debug']['bulksms_mode'] = [
    '#type' => 'select',
    '#title' => 'Operation mode',
    '#options' => [
      'live' => 'live mode',
      'test_succeed' => 'test mode - always succeed',
      'test_fail' => 'test mode - always fail',
    ],
    '#default_value' => variable_get('bulksms_mode', ''),
    '#description' => '"Live mode" will really send SMS messages. Both test modes are for testing purposes only: they do basic validation (username, password, etc) of your submission, but stop short of actually submitting the message, and return a successful status code as if the message was submitted successfully ("always succeed" mode) or a failure code ("always fail" mode).',
  ];
  $form['debug']['bulksms_debug_watchdog'] = [
    '#type' => 'checkbox',
    '#title' => 'Log debug information to watchdog',
    '#default_value' => variable_get('bulksms_debug_watchdog', FALSE),
    '#description' => 'If enabled, will print debug messages of values sent to / received from the gateway.',
  ];
  return system_settings_form($form);
}
